==> meteor-react-materializecss-1.0.20.tgz: package/src/components/contexts/appContext.jsx <==
import React, { createContext, useReducer, useEffect } from "react";
import { AppReducer } from "./appReducer";

export const AppContext = createContext();

const AppContextProvider = ({ baseTitle, children }) => {
  const initialAppState = {
    title: baseTitle,
    selectedMenu: "home",
    pageData: {},
  };
  //reading page data from local storage
  const PAGE_PREFIX = "page-";
  for (let key in localStorage) {
    if (key.startsWith(PAGE_PREFIX)) {
      const page = key.substring(PAGE_PREFIX.length);
      const json = sessionStorage.getItem(key);
      initialAppState.pageData[page] = JSON.parse(json);
    }
  }
  
  const [state, dispatch] = useReducer(AppReducer, initialAppState);

  const setTitle = (payload) => {
    dispatch({ type: "SET_TITLE", payload });
  };

  const setSelectedMenu = (payload) => {
    dispatch({ type: "SET_SELECTED_MENU", payload });
  };

  const setPageData = (pageId, payload) => {
    dispatch({ type: "SET_PAGE_DATA", pageId, payload });
    const json = JSON.stringify(payload);
    sessionStorage.setItem(PAGE_PREFIX + pageId, json);
  };

  /**
   * clenup code, return in useEffect
   */
  const cleanupStateOnDidUnmount = () => {
    setTitle(initialAppState.title);
    setSelectedMenu(initialAppState.selectedMenu);
  };

  const contextValues = {
    setTitle,
    setSelectedMenu,
    setPageData,
    cleanupStateOnDidUnmount,
    ...state,
  };

  return (
    <AppContext.Provider value={contextValues}>{children}</AppContext.Provider>
  );
};

export default AppContextProvider;

==> meteor-react-materializecss-1.0.27.tgz: package/src/components/contexts/appContext.jsx <==
import React, { createContext, useReducer, useEffect } from "react";
import { AppReducer } from "./appReducer";

export const AppContext = createContext();

const AppContextProvider = ({ baseTitle, children }) => {
  const initialAppState = {
    title: baseTitle,
    selectedMenu: "home",
    pageData: {},
  };
  //reading page data from local storage
  const PAGE_PREFIX = "page-";
  for (let key in sessionStorage) {
    if (key.startsWith(PAGE_PREFIX)) {
      const page = key.substring(PAGE_PREFIX.length);
      const json = sessionStorage.getItem(key);
      initialAppState.pageData[page] = JSON.parse(json);
    }
  }
  
  const [state, dispatch] = useReducer(AppReducer, initialAppState);

  const setTitle = (payload) => {
    dispatch({ type: "SET_TITLE", payload });
  };

  const setSelectedMenu = (payload) => {
    dispatch({ type: "SET_SELECTED_MENU", payload });
  };

  const setPageData = (pageId, payload) => {
    dispatch({ type: "SET_PAGE_DATA", pageId, payload });
    const json = JSON.stringify(payload);
    sessionStorage.setItem(PAGE_PREFIX + pageId, json);
  };

  /**
   * clenup code, return in useEffect
   */
  const cleanupStateOnDidUnmount = () => {
    setTitle(initialAppState.title);
    setSelectedMenu(initialAppState.selectedMenu);
  };

  const contextValues = {
    setTitle,
    setSelectedMenu,
    setPageData,
    cleanupStateOnDidUnmount,
    ...state,
  };

  return (
    <AppContext.Provider value={contextValues}>{children}</AppContext.Provider>
  );
};

export default AppContextProvider;
